@@ -46,8 +46,8 @@ CPANPLUS::Selfupdate
             'Locale::Maketext::Simple'  => '0.01',
             'Log::Message'              => '0.01',
             'Module::Load'              => '0.10',
-            'Module::Load::Conditional' => '0.18', # Better parsing: #23995,
-                                                   # uses version.pm for <=>
+            'Module::Load::Conditional' => '0.28', # returns dir for loaded
+                                                   # modules
             'version'                   => '0.73', # needed for M::L::C
                                                    # addresses #24630 and 
                                                    # #24675
@@ -61,7 +61,7 @@ CPANPLUS::Selfupdate
             'Archive::Extract'          => '0.16', # ./Dir bug fix
             'Archive::Tar'              => '1.23',
             'IO::Zlib'                  => '1.04', # needed for Archive::Tar
-            'Object::Accessor'          => '0.32', # overloaded stringification
+            'Object::Accessor'          => '0.34', # mk_aliases support
             'Module::CoreList'          => '2.09',
             'Module::Pluggable'         => '2.4',
             'Module::Loaded'            => '0.01',
